(***********************************************************************
 *
 * Parser.inc version 1.3
 *
 * Copyright (c) 2016 Michel Deslierres
 * All rights reserved. Tous droits rservs.
 *
 * Read full license in the file license.txt
 * Lire la licence au complet dans le fichier license.txt
 *
 ***********************************************************************
 *
 * This file documents the compiler directives used in Simple parser. By
 * default none are defined in this file. In most cases none should be
 * defined in the file. IDE macros are defined in the package file and
 * they should be invoked through compilor options.
 *   Options for Project/Compiler Options/Additions and Overrides
 *
 *  d  d  r
 *  e  e  e
 *  f  b  l
 *  a  u  e
 *  u  g  a
 *  l     s
 *  t     e
 *  
 * Targets: simpleparser
 *
 *  x  x  x  IDE Macro: simpleparser_no_statements:=true
 *  x  x  x  IDE Macro: simpleparser_no_externals:=true
 *  x  x  x  IDE Macro: simpleparser_no_last_results:=true
 *
 * Changements / Changes
 *
 * - version 1.3
 *
 *     Added NO_NLS2, NO_SIGIL, FORCE_SIGIL
 *
 * - version 1.2
 * 
 *     Added NO_TARGET_HINT, NO_LAST_RESULTS, NO_EXTERNALS
 *
 * - version 1.1
 * 
 *     Added EXPONENT_LEFT_ASSOCIATIVE and EUCLIDEAN_DIV_MOD
 *
 *************************************************************************)

{: File with program wide compiler defines }

{$IFNDEF PARSER_INC}
  {$DEFINE PARSER_INC}

    { Define this directive to remove the extension of national language support
      to the translation of target names. Each target can have a local name
      (example, 'racine' for 'sqrt' as in spreadsheets). If NO_NLS is defined,
      NO_NLS2 will automatically be defined.}
  {.DEFINE NO_NLS2}

    { Define this directive to require SSigil prefix for all targets
      created with assign statements. If NO_STATEMENTS is defined, has
      no effect. If defined, NO_SIGIL will be undefined. SSigil is
      defined in ParserTypes.pas.}
  {.DEFINE FORCE_SIGIL}

    { Define this directive to exclude the sigil (SSigil) from identifiers.
      Defining NO_SIGIL is not compatible with FORCE_SIGIL.}
  {.DEFINE NO_SIGIL}

    { Define this directive to prevent the creation of a second list of
      targets called ExternalTargets (in Targets.pas). By default this
      directive is not defined and the list is created and used in 
      assignment statements. The list must be created if statements are
      allowed.}
  {.DEFINE NO_EXTERNALS}

    { Define this directive to disallow acces to the last result as symbol
      $ and second to last result as $$.}
  {.DEFINE NO_LAST_RESULTS}

    { Define this directive to exclude a description of each internal
      target, as well as each external target. By default this directive
      is not defined and targets have hints which are defined in 
      ParserConsts.pas.}
  {.DEFINE NO_TARGET_HINT}

    { If this directive is defined then the div and mod functions
      (':' and '%') will give result corresponding to the Euclidean 
      definitions of those operations. By default this directive is 
      not defined and the result returned is the same as found in Free 
      Pascal and Delphi.}
  {.DEFINE EUCLIDEAN_DIV_MOD}

    { If this directive is defined, then the expression '2^3^4' will be 
      calculated as (2^3)^4. While this may be the how LibreOffice.Calc
      and Excel do it, it seems strange. By default this directive is 
      not defined and the expression '2^3^4' is calculated as 2^(3^4).}
  {.DEFINE EXPONENT_LEFT_ASSOCIATIVE}

    { If this directive is defined then the decimal separator will be
      the period ('.') and the list separator will be the comma (',') no
      matter what the user's locale is. Furthermore the Encode and 
      Decode functions will not convert these values. By default this 
      directive is not defined and the user's locale values are used.
      In Linux/Mac OSX, clocale must be loaded in the project file.}
  {.DEFINE NO_NLS}

    { If this directive is defined, the simple parser will not change
      the FPU exception mask and the ExceptionMask property will not
      be defined. By default the directive is not defined and the FPU 
      exception mask is set to the content of the ExceptionMask before 
      any evaluation of an expression. The 'system' exceptions mask is 
      restored as soon as possible after evaluation including before 
      invoking any exception handler. This conditional must not be 
      defined if using the GTK2 widget set because it assumes that all 
      FPU exceptions are masked.}
  {.DEFINE NO_EXCEPTION_MASK}

    { If the symbol UNIT_INFO is defined then version information about units
      making up the parser is is included in each unit. If the symbol RELEASE is 
      defined, then unit version information will not be included no matter whether 
      UNIT_INFO is defined here.}
  {.DEFINE UNIT_INFO}

 {---- do not change any define below ----}

  {$IFDEF NO_NLS}{$IFnDEF NO_NLS2}
    {$DEFINE NO_NLS2}
  {$ENDIF}{$ENDIF}

  {$IFDEF FORCE_SIGIL}{$IFDEF NO_SIGIL}
    {$UNDEF NO_SIGIL}
  {$ENDIF}{$ENDIF}

  {$IFDEF LCLGTK2}{$IFDEF NO_EXCEPTION_MASK}
    { May get away without playing with fpu exception mask, but not
      when using the the Gtk2 widget set}
    {$UNDEF NO_EXCEPTION_MASK}
  {$ENDIF}{$ENDIF}

  {$IFDEF RELEASE}
     {$UNDEF UNIT_INFO}
  {$ENDIF}
{$ENDIF}
