(***********************************************************************
 *
 * ParserConsts version 1.3
 *
 * Copyright (c) 2016 Michel Deslierres
 * All rights reserved. Tous droits réservés.
 *
 * Read full license in the file license.txt
 * Lire la licence au complet dans le fichier license.txt
 *
 *************************************************************************
 *
 * Changements / Changes
 *
 * - version 1.3
 *
 *     Added optional extended NLS support for targets
 *      - controled with directive NO_NLS2
 *
 * - version 1.2
 *
 *     Modified to handle internal functions and new parser error messages 
 *     related to calls of internal and external functions.
 *
 * - version 1.1
 *
 *     Changed SmeExpectedRightPar message to accomodate different
 *     left, right parenthesis combinations
 *
 *************************************************************************)

{: Unit with string contants for parser.}
 unit ParserConsts;

{$IFDEF FPC}
  {$mode objfpc}
  {$h+ }
{$ENDIF}

{$I parser.inc}

interface

uses
  ParserTypes;

{$IFDEF UNIT_INFO}
const
  SVersionName = 'ParserConsts';
  SVersion = '1.3';
  VersionMajor = 1;
  VersionMinor = 3;
{$ENDIF}

const
  {$IFnDEF NO_SIGIL}
  SSigil = '_';
  {$ENDIF}

  // English language names of internal functions
  // These are constants that are not to be translated
  SC_abs = 'abs';
  SC_acos = 'acos';
  SC_acosh = 'acosh';
  SC_acot = 'acot';
  SC_acoth = 'acoth';
  SC_acsc = 'acsc';
  SC_acsch = 'acsch';
  SC_asec = 'asec';
  SC_asech = 'asech';
  SC_asin = 'asin';
  SC_asinh = 'asinh';
  SC_atan = 'atan';
  SC_atanh = 'atanh';
  SC_avg = 'avg';
  SC_ceil = 'ceil';
  SC_clamp = 'clamp';
  SC_cos = 'cos';
  SC_cosh = 'cosh';
  SC_cot = 'cot';
  SC_coth = 'coth';
  SC_csc = 'csc';
  SC_csch = 'csch';
  SC_deg = 'deg';
  SC_div = 'div';
  SC_e = 'e';
  SC_exp = 'exp';
  SC_fact = 'fact';
  SC_floor = 'floor';
  SC_int = 'int';
  SC_ln = 'ln';
  SC_log = 'log';
  SC_log10 = 'log10';
  SC_max = 'max';
  SC_min = 'min';
  SC_mod = 'mod';
  SC_odd = 'odd';
  SC_pi = 'pi';
  SC_poly = 'poly';
  SC_rad = 'rad';
  SC_round = 'round';
  SC_sec = 'sec';
  SC_sech = 'sech';
  SC_sgn = 'sgn';
  SC_sin = 'sin';
  SC_sinh = 'sinh';
  SC_sqr = 'sqr';
  SC_sqrt = 'sqrt';
  SC_ssq = 'ssq';
  SC_tan = 'tan';
  SC_tanh = 'tanh';
  SC_var = 'var';
  SC_varp = 'varp';


  {$IFnDEF NO_NLS2}
  // English language names of internal functions declared as
  // resource string to allow gnuqettext style translation.
resourcestring
    SR_abs = 'abs';
    SR_acos = 'acos';
    SR_acosh = 'acosh';
    SR_acot = 'acot';
    SR_acoth = 'acoth';
    SR_acsc = 'acsc';
    SR_acsch = 'acsch';
    SR_asec = 'asec';
    SR_asech = 'asech';
    SR_asin = 'asin';
    SR_asinh = 'asinh';
    SR_atan = 'atan';
    SR_atanh = 'atanh';
    SR_avg = 'avg';
    SR_ceil = 'ceil';
    SR_clamp = 'clamp';
    SR_cos = 'cos';
    SR_cosh = 'cosh';
    SR_cot = 'cot';
    SR_coth = 'coth';
    SR_csc = 'csc';
    SR_csch = 'csch';
    SR_deg = 'deg';
    SR_div = 'div';
    SR_e = 'e';
    SR_exp = 'exp';
    SR_fact = 'fact';
    SR_floor = 'floor';
    SR_int = 'int';
    SR_ln = 'ln';
    SR_log = 'log';
    SR_log10 = 'log10';
    SR_max = 'max';
    SR_min = 'min';
    SR_mod = 'mod';
    SR_odd = 'odd';
    SR_pi = 'pi';
    SR_poly = 'poly';
    SR_rad = 'rad';
    SR_round = 'round';
    SR_sec = 'sec';
    SR_sech = 'sech';
    SR_sgn = 'sgn';
    SR_sin = 'sin';
    SR_sinh = 'sinh';
    SR_sqr = 'sqr';
    SR_sqrt = 'sqrt';
    SR_ssq = 'ssq';
    SR_tan = 'tan';
    SR_tanh = 'tanh';
    SR_var = 'var';
    SR_varp = 'varp';
  {$ENDIF}

{$IFnDEF NO_TARGET_HINT}
  {$IFnDEF NO_NLS2}
resourcestring
  {$ELSE}
const
  {$ENDIF}
  S_abs_Hint = 'Returns the absolute value';
  S_acos_Hint = 'Returns the inverse cosine';
  S_acosh_Hint = 'Returns the inverse hyperbolic cosine';
  S_acot_Hint = 'Returns the inverse cotangent';
  S_acoth_Hint = 'Returns the inverse hyperbolic cotangent';
  S_acsc_Hint = 'Returns the inverse consecant';
  S_acsch_Hint = 'Returns the inverse hyperbolic cosecant';
  S_asec_Hint = 'Returns the inverse secant';
  S_asech_Hint = 'Returns the inverse hyperbolic secant';
  S_asin_Hint = 'Returns the inverse sine';
  S_asinh_Hint = 'Returns the inverse hyperbolic sine';
  S_atan_Hint = 'Returns the inverse tangent';
  S_atanh_Hint = 'Returns the inverse hyperbolic tangent';
  S_avg_Hint = 'Returns the average of values in the list';
  S_ceil_Hint = 'Returns the smallest larger or equal integer';
  S_clamp_Hint = 'Returns the value clamped to bounds';
  S_cos_Hint = 'Returns the cosine';
  S_cosh_Hint = 'Returns the hyperbolic cosine';
  S_cot_Hint = 'Returns the cotangent';
  S_coth_Hint = 'Returns the hyperbolic cotangent';
  S_csc_Hint = 'Returns the cosecant';
  S_csch_Hint = 'Returns the hyperbolic cosecant';
  S_deg_Hint = 'Returns radians as degrees';
  S_div_Hint = 'Infix integer division';
  S_e_Hint = 'Euler''s number';
  S_exp_Hint = 'Returns the exponential';
  S_fact_Hint = 'Returns the factorial';
  S_floor_Hint = 'Returns the largest smaller or equal integer';
  S_int_Hint = 'Returns the integer part';
  S_ln_Hint = 'Returns natural logarithm';
  S_log_Hint = 'Returns the logarithm with given base';
  S_log10_Hint = 'Returns the common logarithm';
  S_max_Hint = 'Returns the greatest value in the list';
  S_min_Hint = 'Returns the smallest value in the list';
  S_mod_Hint = 'Infix modulo (division remainder)';
  S_odd_Hint = 'Returns 1 if odd, 0 if even';
  S_pi_Hint = 'The ratio of the circumference of a circle to its diameter';
  S_poly_Hint = 'Returns the value of the polynomial';
  S_rad_Hint = 'Returns degrees as radians';
  S_round_Hint = 'Returns the nearest integer';
  S_sec_Hint = 'Returns the secant';
  S_sech_Hint = 'Returns the hyperbolic secant';
  S_sgn_Hint = 'Returns the sign';
  S_sin_Hint = 'Returns the sine';
  S_sinh_Hint = 'Returns the hyperbolic sine';
  S_sqr_Hint = 'Returns the square';
  S_sqrt_Hint = 'Returns the square root';
  S_ssq_Hint = 'Returns the sum of squares of values in the list';
  S_tan_Hint = 'Returns the tangent';
  S_tanh_Hint = 'Returns the hyperbolic tangent';
  S_var_Hint = 'Returns the estimated variance';
  S_varp_Hint = 'Returns the population variance';
{$ENDIF}

{$IFDEF NO_NLS2}
const
{$ELSE}
resourcestring
{$ENDIF}
  SParseError = 'Parse error';
  SmeNoError = 'No error';
  SmeUnexpectedEOS = 'unexpected end of source';
  SmeExpectedEOS = 'expected end of source';
  SmeInvalidNumber = 'invalid number';
  SmeUnexpectedElement = 'unexpected element';
  SmeExpectedRightPar = 'expected matching right parenthesis';
  SmeExpectedSeparator = 'expected list separator';
  SmeExpectedLeftPar = 'expected "("';
  SmeUnknownIdentifier = 'unknown function or constant';
  SmeTooFewParams = 'missing parameters';
  SmeTooManyParams = 'too many parameters';
  SmeOtherError = 'Error: %s';
  SmeEvalError = 'Evaluation error: %s';

  {Returns an errror message based on the specified TParserError. The
   parser's list char must also be given.}
function ParserErrorMessage(value: TParserError): string;

implementation

uses
  SysUtils;

function ParserErrorMessage(value: TParserError): string;
begin
  case value of
    meUnexpectedEOS: result := SmeUnexpectedEOS;
    meExpectedEOS: result := SmeExpectedEOS;
    meInvalidNumber: result := SmeInvalidNumber;
    meUnexpectedElement: result := SmeUnexpectedElement;
    meExpectedRightPar: result := SmeExpectedRightPar;
    meExpectedSeparator: result := SmeExpectedSeparator;
    meExpectedLeftPar: result := SmeExpectedLeftPar;
    meUnknownIdentifier: result := SmeUnknownIdentifier;
    meTooFewParams: result := SmeTooFewParams;
    meTooManyParams: result := SmeTooManyParams;
  else
    {$IFDEF DEBUG}
    assert(false, Format('unknown parser error #%d',[ord(value)]));
    {$ENDIF}
  end;
  result := Format('%s, %s', [sParseError, result]);
end;

end.
